#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Mon Oct  8 11:26:44 2018

@author: patrickmcfarlane

__init__.py

This script initializes the py_ball package
"""

name = 'py_ball'

__all__ = ['league', 'image', 'utils']
